

/*

________________________________________________________________

        ImageP.h
        %W% %E%, Copyright 1990, Blab, UiO
        Image processing lab, Department of Informatics
        University of Oslo
        E-mail: blab@uio.no
________________________________________________________________
  
  Permission to use, copy, modify and distribute this software and its
  documentation for any purpose and without fee is hereby granted, 
  provided that this copyright notice appear in all copies and that 
  both that copyright notice and this permission notice appear in supporting
  documentation and that the name of B-lab, Department of Informatics or
  University of Oslo not be used in advertising or publicity pertaining 
  to distribution of the software without specific, written prior permission.

  B-LAB DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL B-LAB
  BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
  OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
  CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 

*/


#ifndef _ImageP_h
#define _ImageP_h

#include "Image.h"
/* include superclass private header file */
#include <X11/CoreP.h>
#include <X11/CompositeP.h>

/* define unique representation types not found in <X11/StringDefs.h> */

#define XtRImageResource		"ImageResource"

typedef struct ipixelstruct
{
  char *pixelname;
  int  pixelsize;
  resizefunc resize;
  printffunc printf;
  int txtlen;
  int scaletype;
  float scalea, scaleb;
  float minval, maxval;
  struct ipixelstruct *next;
} ipixel, *pixelptr;


typedef struct {
  int count, widget_list_length;
  Widget *widget_list;
  pixelptr pixel_class;
  int zoom_all;
} ImageClassPart;


typedef struct _ImageClassRec {
    CoreClassPart	core_class;
    CompositeClassPart  composite_class;
    ImageClassPart	image_class;
} ImageClassRec;

extern ImageClassRec imageClassRec;

typedef struct {

    /* resources */
    struct imagestruct *image;
    struct bandstruct  *band;
    struct bandstruct  *red_band, *green_band, *blue_band;
    ImageData          data, red_data, green_data, blue_data;
    char               *title;
    char 	       *pixname;
    int                print_values;
    int                width, height, line_length;
    int                xstart, ystart;
    int                displaymethod;
    int                scaletype;
    float	       scalea, scaleb, minval, maxval;
    Visual             *visual;
    XFontStruct        *font[5];
    XtCallbackList     button_action;
    XtCallbackList     resize_action;

    /* private state */
    int               internal_width;
    int               internal_height;
    int		      has_colormap;
    int		      planes;
    int		      cells;
    XImage            *ximg;
    GC                gc;
    XFontStruct       *font_info;
    int               update;
    int               resize;
    double            factor;
    float             zoom;
    int               xpan, ypan;
    int               *xptr, *yptr;
    int               colortab;
    pixelptr 	      pixtype;
    int 	      updatex, updatey, updatew, updateh;
} ImagePart;

typedef struct _ImageRec {
    CorePart	    core;
    CompositePart   composite;
    ImagePart	    image;
} ImageRec;

#endif  _ImageP_h


